-- Projet ASIC FIR16
-- Test Bench de l'ensemble du fir16

-- Olivier Sentieys avril 2000

-- En entree : les signaux de l'interface parallele
-- En sortie : le signal filtre Y envoye en parallele, un signal fin

-- Test Bench : Envoi de 16 fois la valeur 32 
--		puis de 16 fois la valeur 0 puis d'une impulsion


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_arith.all;

library work;
use work.all;
 
 
entity test_fir16 is
end test_fir16;

architecture test of test_fir16 is

-- Signaux externes de fir16
signal Clk : std_logic;
signal Rst : std_logic;

signal Fin : std_logic;

constant Tcycle : TIME := 100 ns;
constant Tsample : TIME := 10 us;

signal x : integer range 0 to 255 := 0;
signal y : integer range 0 to 65535 := 0;
signal yf : real := 0.0;

-- composants
component fir16
    port ( xn : in integer range 0 to 255; 
	   yn : out integer range 0 to 65535;
	   clk, rst : in Std_Logic );
end component;


begin

ASIC : fir16 PORT MAP (x, y, clk, rst) ;
			
	
 horloge : process
  begin
    clk <= '0';
    wait for 0 ns;
    while true loop
      clk <= '1';
      wait for Tcycle/2;
      clk <= '0';
      wait for Tcycle/2;
    end loop;
  end process;
  
  yf <= real(y) / 128.0;
  
  main : process
  begin
  	-- Valeur au reset
        rst <= '1';
        fin <= '1';
	wait for 200 ns;
        rst <= '0';
  	wait for 500 ns;
     
        fin <= '0';
	x <= 32;
	wait for 16*Tcycle;
	-- Fin de la trame de 16 echantillons
	-- Envoi de 16 fois la valeur 32 (reponse indicielle / 4)
	
	x <= 0;
	wait for 16*Tcycle;
	-- Envoi de 16 fois la valeur 0

	x <= 127;
	wait for Tcycle;	
	x <= 0;
	wait for 15*Tcycle;
	-- Fin de la trame de 16 echantillons
	-- Envoi de la valeur 127 puis 15 fois la valeur 0 (reponse impulsionnelle)
	
	x <= 0;
	wait for 5*Tcycle;
	-- Envoi de 5 fois la valeur 0  	
	
	wait;
  end process;

end test;

-- Configuration
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_arith.all;

library work;
use work.all;

configuration cfg_fir16 of test_fir16 is

	for test
		for ASIC:fir16
			use entity work.fir16(behavioral_fir16);
		end for;
	end for;
	
end cfg_fir16;
